@@ -18,5 +18,5 @@ class SARSA(TD):
         self.next_action = self.draw_action(next_state)
         q_next = self.Q[next_state, self.next_action] if not absorbing else 0.
 
-        self.Q[state, action] = q_current + self.alpha(state, action) * (
+        self.Q[state, action] = q_current + self._alpha(state, action) * (
             reward + self.mdp_info.gamma * q_next - q_current)
